@@ -64,6 +64,7 @@ typedef enum dc_field_type_t {
 	DC_FIELD_TANK,
 	DC_FIELD_DIVEMODE,
 	DC_FIELD_DECOMODEL,
+	DC_FIELD_LOCATION,
 } dc_field_type_t;
 
 typedef enum parser_sample_event_t {
@@ -141,12 +142,21 @@ typedef struct dc_salinity_t {
 	double density;
 } dc_salinity_t;
 
+typedef enum dc_usage_t {
+	DC_USAGE_NONE,
+	DC_USAGE_OXYGEN,
+	DC_USAGE_DILUENT,
+	DC_USAGE_SIDEMOUNT,
+} dc_usage_t;
+
 typedef struct dc_gasmix_t {
 	double helium;
 	double oxygen;
 	double nitrogen;
+	dc_usage_t usage;
 } dc_gasmix_t;
 
+#define DC_SENSOR_NONE    0xFFFFFFFF
 #define DC_GASMIX_UNKNOWN 0xFFFFFFFF
 
 typedef enum dc_tankvolume_t {
@@ -185,6 +195,7 @@ typedef struct dc_tank_t {
     double workpressure;  /* Work pressure (bar) */
     double beginpressure; /* Begin pressure (bar) */
     double endpressure;   /* End pressure (bar) */
+    dc_usage_t usage;
 } dc_tank_t;
 
 typedef enum dc_decomodel_type_t {
@@ -224,8 +235,20 @@ typedef struct dc_decomodel_t {
 	} params;
 } dc_decomodel_t;
 
+/*
+ * GPS Location
+ *
+ * The latitude and longitude are in decimal degrees, and the (optional)
+ * altitude in meters.
+ */
+typedef struct dc_location_t {
+	double latitude;
+	double longitude;
+	double altitude;
+} dc_location_t;
+
 typedef union dc_sample_value_t {
-	unsigned int time;
+	unsigned int time; /* Milliseconds */
 	double depth;
 	struct {
 		unsigned int tank;
@@ -247,25 +270,29 @@ typedef union dc_sample_value_t {
 		const void *data;
 	} vendor;
 	double setpoint;
-	double ppo2;
+	struct {
+		unsigned int sensor;
+		double value;
+	} ppo2;
 	double cns;
 	struct {
 		unsigned int type;
 		unsigned int time;
 		double depth;
+		unsigned int tts;
 	} deco;
 	unsigned int gasmix; /* Gas mix index */
 } dc_sample_value_t;
 
 typedef struct dc_parser_t dc_parser_t;
 
-typedef void (*dc_sample_callback_t) (dc_sample_type_t type, dc_sample_value_t value, void *userdata);
+typedef void (*dc_sample_callback_t) (dc_sample_type_t type, const dc_sample_value_t *value, void *userdata);
 
 dc_status_t
-dc_parser_new (dc_parser_t **parser, dc_device_t *device);
+dc_parser_new (dc_parser_t **parser, dc_device_t *device, const unsigned char data[], size_t size);
 
 dc_status_t
-dc_parser_new2 (dc_parser_t **parser, dc_context_t *context, dc_descriptor_t *descriptor, unsigned int devtime, dc_ticks_t systime);
+dc_parser_new2 (dc_parser_t **parser, dc_context_t *context, dc_descriptor_t *descriptor, const unsigned char data[], size_t size);
 
 dc_family_t
 dc_parser_get_type (dc_parser_t *parser);
@@ -279,9 +306,6 @@ dc_parser_set_atmospheric (dc_parser_t *parser, double atmospheric);
 dc_status_t
 dc_parser_set_density (dc_parser_t *parser, double density);
 
-dc_status_t
-dc_parser_set_data (dc_parser_t *parser, const unsigned char *data, unsigned int size);
-
 dc_status_t
 dc_parser_get_datetime (dc_parser_t *parser, dc_datetime_t *datetime);
 
